OC.L10N.register(
    "photos",
    {
    "Photos" : "写真",
    "Your memories under your control" : "あなたの思い出はあなたが管理しましょう",
    "Your photos" : "写真",
    "Your videos" : "動画",
    "Favorites" : "お気に入り",
    "Your folders" : "フォルダー",
    "Shared with you" : "共有中",
    "Tagged photos" : "タグ付けされた写真",
    "Locations" : "場所",
    "Settings" : "設定",
    "Open the full size \"{name}\" image" : "画像 \"{name}\" をフルサイズで開く",
    "Open the \"{name}\" sub-directory" : "サブディレクトリ \"{name}\" を開く",
    "Share this folder" : "このフォルダーを共有する",
    "Back to {folder}" : " {folder} に戻る",
    "View" : "表示",
    "Enable squared photos view" : "写真を矩形での表示を有効化",
    "This folder does not exist" : "このフォルダーは存在しません",
    "An error occurred" : "エラーが発生しました",
    "No photos in here" : "写真がありません",
    "No tags yet" : "まだタグがありません",
    "Photos with tags will show up here" : "タグ付けされた写真がここに表示されます"
},
"nplurals=1; plural=0;");
